if [ -f $HOME/path-add-function ]; then
  . $HOME/path-add-function
  path-add /usr/sbin /usr/local/sbin /sbin /a/exe /a/opt/bin
  path-add --end $HOME/.cabal/bin

  if [ -r /etc/alternatives/java_sdk ]; then
    export JAVA_HOME=/etc/alternatives/java_sdk
    path-add /etc/alternatives/java_sdk
  fi

  export GUIX_PROFILE=/root/.config/guix/current
  if [[ -e $GUIX_PROFILE/etc/profile ]]; then
    source $GUIX_PROFILE/etc/profile
  fi
  path-add $HOME/.guix-profile/bin
  export GUIX_LOCPATH=$HOME/.guix-profile/lib/locale

fi


export EDITOR="emacsclient"
# this makes emacsclient file/-c start a server instance if none is running,
# instead of some alternate editor logic
export ALTERNATE_EDITOR=""

export PITHOSFLY_SAVE_DIR=/a/pandora_rips4

# makes subsequent syscalls to localtime use cached timezone,
# so basically restart the comp if you change time zones,
# and avoid a few syscalls, which makes a tiny tiny perf difference.
# I also set this in
# /a/c/filesystem/etc/systemd/system.conf.d/tz.conf
# https://blog.packagecloud.io/eng/2017/02/21/set-environment-variable-save-thousands-of-system-calls/
export TZ=:/etc/localtime

# ubuntu starts gpg agent automatically with  /etc/X11/Xsession.d/90gpg-agent.
# fedora doesn't, which left me to figure this out, and google was no help.
# fedora documentation is often quite bad :(
# This is mostly copied from that file.
# Main difference is that we eval the result of starting gpg-agent,
# while that file executes it through xsession specific var.
# Also make sourcing the pidfile make more sense.
# End result should be the same afaik.
# for gpg-agent to work when calling gpg from the command line,
# we need an environment variable that is setup via the eval.
# which is why we do this upon login, so it can propogate
# It is also written to the file $HOME/.gnupg/gpg-agent-info-$(hostname)
# I'm not aware if that is ever used, but just fyi.
# I also added the bit about xmessaging the stderr,
# because I'd like to know if the command fails
if [ -f /etc/fedora-release ]; then
  : ${GNUPGHOME=$HOME/.gnupg}

  GPGAGENT=/usr/bin/gpg-agent
  PID_FILE="$GNUPGHOME/gpg-agent-info-$(hostname)"

  if ! $GPGAGENT 2>/dev/null; then
    temp="$(mktemp)"
    eval "$($GPGAGENT --homedir /p/do-not-delete --daemon --sh --write-env-file=$PID_FILE 2>$temp)"
    temperr="$(<"$temp")"
    [ -n "$temperr" ] && xmessage "gpg-agent stderr: $temperr"
  elif [ -r "$PID_FILE" ]; then
    . "$PID_FILE"
    export GPG_AGENT_INFO
  fi
fi

# background:
# ubuntu has 002 for non-system users, debian has 022.  002 makes groups
# be rw instead of r.
#
# I think the actual setting is somewhere in the pam settings, I haven't
# bothered to figure that out.
#
# ubuntu is more user friendly when using multiple users. However,
# it also makes it so if you create a file as a regular user then move
# it to become a system file, it's got slightly wrong permissions, and
# sometimes thing break. Also, copying files between ubuntu and debian
# makes things inconsistent. So stick with 022 umask always.
#
# One security concern is where some unixes put every user in a same
# group, so if you copy files there with exact perms, that is probably
# not what you want. I don't use a system like that, so I don't
# care.
umask 022
# this is how we could test for non-system user

#if test "$(id -u)" -ge 1000; then : fi
